@@ -31,7 +31,7 @@ class StrategyTask(BaseTask):
             try:
                 time.sleep(1)
                 symbol = symbol_info['symbol']
-                if not symbol.startswith("BTC"):
+                if not symbol.startswith("BTC/"):
                     continue
 
                 if not symbol.endswith('BUSD'):
